@@ -4,8 +4,8 @@
 #' the Botev (2010) bandwidth selector and the Abramson (1982)
 #' adaptive kernel bandwidth modifier.
 #'
-#' @param x a vector of numbers or an object of class \code{UPb} or
-#'     \code{detrital}
+#' @param x a vector of numbers or an object of class \code{UPb},
+#'     \code{ArAr} or \code{detrital}
 #' @rdname kde
 #' @export
 kde <- function(x,...){ UseMethod("kde",x) }
@@ -95,32 +95,10 @@ kde.default <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
 kde.UPb <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
                     n=512,plot=TRUE,pch=NA,xlab="age [Ma]",ylab="",
                     kde.col=rgb(1,0,1,0.6),hist.col=rgb(0,1,0,0.2),
-                    show.hist=TRUE, bty='n',binwidth=NA, ncol=NA,
+                    show.hist=TRUE, bty='n',binwidth=NA,ncol=NA,
                     type=4,cutoff.76=1100,cutoff.disc=c(-15,5),...){
-    tt <- UPb.age(x)
-    do.76 <- tt[,'t.68'] > cutoff.76
-    if (any(is.na(cutoff.disc))) {
-        is.concordant <- rep(TRUE,nrow(x))
-    } else {
-        disc.75.68 <- 100*(1-tt[,'t.75']/tt[,'t.68'])
-        disc.68.76 <- 100*(1-tt[,'t.68']/tt[,'t.76'])
-        is.concordant <- (disc.75.68>cutoff.disc[1] & disc.75.68<cutoff.disc[2]) |
-                         (disc.68.76>cutoff.disc[1] & disc.68.76<cutoff.disc[2])
-    }
-    if (type==1){
-        ttt <- tt[,'t.75']
-    } else if (type==2){
-        ttt <- tt[,'t.68']
-    } else if (type==3){
-        ttt <- tt[,'t.76']
-    } else if (type==4){
-        i.76 <- as.vector(which(do.76 & is.concordant))
-        i.68 <- as.vector(which(!do.76 & is.concordant))
-        ttt <- c(tt[i.68,'t.68'],tt[i.76,'t.76'])
-    } else if (type==4){
-        ttt <- tt[,'t.conc']
-    }
-    kde.default(ttt,from=from,to=to,bw=bw,adaptive=adaptive,log=log,
+    tt <- filter.UPb.ages(x,type,cutoff.76,cutoff.disc)[,1]
+    kde.default(tt,from=from,to=to,bw=bw,adaptive=adaptive,log=log,
                 n=n,plot=plot,pch=pch,xlab=xlab,ylab=ylab,
                 kde.col=kde.col, hist.col=hist.col,
                 show.hist=show.hist,bty=bty,binwidth=binwidth,
@@ -166,6 +144,19 @@ kde.detritals <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,
         return(X)
     }
 }
+#' @rdname kde
+#' @export
+kde.ArAr <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
+                    n=512,plot=TRUE,pch=NA,xlab="age [Ma]",ylab="",
+                    kde.col=rgb(1,0,1,0.6),hist.col=rgb(0,1,0,0.2),
+                    show.hist=TRUE,bty='n',binwidth=NA,ncol=NA,...){
+    tt <- ArAr.age(x)[,1]
+    kde.default(tt,from=from,to=to,bw=bw,adaptive=adaptive,log=log,
+                n=n,plot=plot,pch=pch,xlab=xlab,ylab=ylab,
+                kde.col=kde.col, hist.col=hist.col,
+                show.hist=show.hist,bty=bty,binwidth=binwidth,
+                ncol=ncol,...)
+}
 
 # helper functions for the generic kde function
 getkde <- function(x,...){ UseMethod("getkde",x) }
@@ -174,21 +165,21 @@ getkde.default <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,n=512,.
     class(out) <- "KDE"
     out$name <- deparse(substitute(x))
     out$log <- log
+    if (log) d <- log(x)
+    else d <- x
+    if (is.na(bw)) bw <- botev(d)
     if (is.na(from) | is.na(to)) {
         mM <- getmM(x,from,to,log)
+        to <- mM$M + bw
         from <- mM$m
-        to <- mM$M
+        if (mM$m > bw) from <- from - bw
     }
     if (log) {
-        d <- log(x)
+        bw <- bw/(stats::median(x))
         from <- log(from)
         to <- log(to)
-        bw <- bw/(stats::median(x))
-    } else {
-        d <- x
     }
     out$x <- seq(from=from,to=to,length.out=n)
-    if (is.na(bw)){ bw <- botev(d) }
     if (adaptive){
         out$y <- Abramson(d,from=from,to=to,bw=bw,n=n,...)
     } else {
@@ -295,7 +286,9 @@ plot.KDE <- function(x,pch='|',xlab="age [Ma]",ylab="",
         h <- graphics::hist(ages,breaks=breaks,plot=FALSE)
     }
     nb <- length(breaks)-1
-    graphics::plot(x$x,x$y,type='n',log=do.log,
+    maxy <- max(x$y)
+    if (show.hist) maxy <- max(maxy,max(h$density))
+    graphics::plot(range(x$x),c(0,maxy),type='n',log=do.log,
                    xlab=xlab,ylab=ylab,yaxt='n',bty=bty,...)
     if (show.hist){
         graphics::rect(xleft=breaks[1:nb],xright=breaks[2:(nb+1)],
@@ -310,7 +303,7 @@ plot.KDE <- function(x,pch='|',xlab="age [Ma]",ylab="",
     graphics::polygon(x$x,x$y,col=kde.col)
     graphics::lines(x$x,x$y,col='black')
     graphics::points(ages,rep(graphics::par("usr")[3]/2,length(ages)),pch=pch)
-    graphics::text(M,max(x$y),paste0("n=",length(ages)),pos=2)
+    graphics::text(M,maxy,paste0("n=",length(ages)),pos=2)
 }
 
 plot.KDEs <- function(x,ncol=NA,pch=NA,xlab="age [Ma]",ylab="",
